<?php
/**
 * Finance Advisor functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Finance_Advisor
 */

if ( ! defined( 'finance_advisor_version' ) ) {
	// Replace the version number of the theme on each release.
	define( 'finance_advisor_version', '1.0.0' );
}

if ( ! function_exists( 'finance_advisor_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function finance_advisor_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Finance Advisor, use a find and replace
		 * to change 'finance-advisor' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'finance-advisor', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );
		add_image_size('finance_advisor_about_team_img', 384,420,true);

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus(
			array(
				'menu-1' => esc_html__( 'Primary', 'finance-advisor' ),
			)
		);

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support(
			'html5',
			array(
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
				'style',
				'script',
			)
		);

		// Set up the WordPress core custom background feature.
		add_theme_support(
			'custom-background',
			apply_filters(
				'finance_advisor_custom_background_args',
				array(
					'default-color' => 'ffffff',
					'default-image' => '',
				)
			)
		);

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support(
			'custom-logo',
			array(
				'height'      => 250,
				'width'       => 250,
				'flex-width'  => true,
				'flex-height' => true,
			)
		);
	}
endif;
add_action( 'after_setup_theme', 'finance_advisor_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function finance_advisor_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'finance_advisor_content_width', 640 );
}
add_action( 'after_setup_theme', 'finance_advisor_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function finance_advisor_widgets_init() {
	register_sidebar(
		array(
			'name'          => esc_html__( 'Sidebar', 'finance-advisor' ),
			'id'            => 'sidebar-1',
			'description'   => esc_html__( 'Add widgets here.', 'finance-advisor' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);
}
add_action( 'widgets_init', 'finance_advisor_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function finance_advisor_scripts() {
	// Add custom fonts, used in the main stylesheet.
  	wp_enqueue_style( 'finance-advisor-fonts', finance_advisor_fonts_url(), array(), null );

	// Add font awesome icons
	wp_enqueue_style('fontAwesome', get_template_directory_uri() . '/inc/font-awesome/css/fontawesome-all.min.css', array(), '5.0.2' );

	// additional css
	wp_enqueue_style('finance-advisor-additional-css', get_template_directory_uri() . '/assets/styles/css/main.css', array(), '1.0.0' );

	wp_enqueue_style( 'finance-advisor-style', get_stylesheet_uri(), array(), finance_advisor_version );
	wp_style_add_data( 'finance-advisor-style', 'rtl', 'replace' );

	// nativation js
	wp_enqueue_script( 'finance-advisor-main-navigation', get_template_directory_uri() . '/assets/js/navigation.js', array('jquery'), finance_advisor_version, true );

	wp_enqueue_script( 'finance-advisor-skip-link-focus-fix', get_template_directory_uri() . '/assets/js/skip-link-focus-fix.js', array('jquery'), finance_advisor_version, true );

	// main theme js
	wp_enqueue_script( 'finance-advisor-main-js', get_template_directory_uri() . '/js/main.js', array('jquery'), '1.0.0', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'finance_advisor_scripts' );


/**
 * Register Google fonts.
 * @return string Google fonts URL for the theme.
 */

if ( ! function_exists( 'finance_advisor_fonts_url' ) ) :
	function finance_advisor_fonts_url() {
		$finance_advisor_fonts_url = '';
		$finance_advisor_fonts     = array();
			
		// Translators: If there are characters in your language that are not supported by Open Sans, translate this to 'off'. Do not translate into your own language. 
		if ( 'off' !== esc_html_x( 'on', 'Oswald font: on or off', 'finance-advisor' ) ) {
			$finance_advisor_fonts[] = 'Oswald:200,300,400,500,600,700';
		}
				
	
		if ( $finance_advisor_fonts ) {
			$finance_advisor_fonts_url = add_query_arg( array(
				'family' => urlencode( implode( '|', $finance_advisor_fonts ) ),
				'subset' => urlencode( 'latin,latin-ext' ),
			), 'https://fonts.googleapis.com/css' );
		}
	
		return $finance_advisor_fonts_url;
	}
	endif;

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

/*include category dropdown*/
require get_template_directory() . '/inc/category-dropdown.php';


/** Theme info page */
require get_template_directory() . '/inc/blaze-upsells/theme-info.php';

/** upsell */

require get_template_directory() . '/inc/blaze-upsells/blaze-pro-btn/class-customize.php';

