<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package Finance_Advisor
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function finance_advisor_body_classes( $classes ) {
	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	// Adds a class of no-sidebar when there is no sidebar present.
	if ( ! is_active_sidebar( 'sidebar-1' ) ) {
		$classes[] = 'no-sidebar';
	}

	// Add page slug if it doesn't exist
  if (is_single() || is_page() && !is_front_page()) {
    if (!in_array(basename(get_permalink()), $classes)) {
      $classes[] = basename(get_permalink());
    }
  }

	return $classes;
}
add_filter( 'body_class', 'finance_advisor_body_classes' );

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function finance_advisor_pingback_header() {
	if ( is_singular() && pings_open() ) {
		printf( '<link rel="pingback" href="%s">', esc_url( get_bloginfo( 'pingback_url' ) ) );
	}
}
add_action( 'wp_head', 'finance_advisor_pingback_header' );

/*
=================================================
Homepage Banner Section Function
@Action: finance_advisor_banner_home
=================================================
*/
if ( ! function_exists( 'finance_advisor_banner_home_fnc' ) ) :

	function finance_advisor_banner_home_fnc(){ 
		if (has_post_thumbnail(get_the_ID())){
			$finance_advisor_bg_img = get_the_post_thumbnail_url( get_the_ID() );
		}else{
			$finance_advisor_bg_img = get_header_image();
		}

		$finance_advisor_title = get_the_title();
		$finance_advisor_sub_title = get_the_excerpt();
		$finance_advisor_link_url = get_theme_mod('banner_readmore_link');
		

		if($finance_advisor_bg_img):
			?>
			<section class="banner" style="background-image: url(<?php echo esc_url ($finance_advisor_bg_img); ?>);">
				<span class="overlay"></span>
				<div class="container">

					<div class="banner-content">
						<?php if($finance_advisor_title) : ?>
							<h1 class="banner-heading">
								<?php echo esc_html($finance_advisor_title);?>
							</h1>
						<?php endif; ?>
						<?php if($finance_advisor_sub_title) : ?>
							<div class="content">
								<p><?php echo esc_html($finance_advisor_sub_title); ?></p>
							</div>
						<?php endif; ?>
						<?php if($finance_advisor_link_url) : ?>
						<div class="link-block">
							<a href="<?php echo esc_url($finance_advisor_link_url); ?>"><?php esc_html_e('Read More', 'finance-advisor'); ?></a>
						</div>
						<?php endif; ?>
					</div>

				</div>
			</section>

			<?php 
		endif;
	}
endif;


/*
=================================================
Innerpage Banner Section Function
@Action: finance_advisor_banner_inner
=================================================
*/
if ( ! function_exists( 'finance_advisor_banner_inner_fnc' ) ) :

	function finance_advisor_banner_inner_fnc(){ 
		if (has_post_thumbnail(get_the_ID())){
			$finance_advisor_bg_img = get_the_post_thumbnail_url( get_the_ID() );
		}else{
			$finance_advisor_bg_img = get_header_image();
		}
		
		if($finance_advisor_bg_img):
			?>
			<section class="banner" style="background-image: url(<?php echo esc_url ($finance_advisor_bg_img); ?>);">
				<span class="overlay"></span>
				<div class="container">
					
					<div class="banner-content">
						<?php
							if( is_archive() ){
								the_archive_title( '<h1 class="banner-heading">', '</h1>' );
								the_archive_description( '<div class="content"><p>', '</p></div>' );
							}else{
								the_title('<h1 class="banner-heading">', '</h1>');
							}
						?>
					</div>
				</div>
			</section>
			<?php 
		endif;
	}
endif;


/*
=================================================
About us section 
@Action: finance_advisor_about_us_section
=================================================
*/
if ( ! function_exists( 'finance_advisor_about_us_section_fnc' ) ) :

	function finance_advisor_about_us_section_fnc(){ 
		$finance_advisor_about_us_id = get_theme_mod('finance_advisor_dropdownpages_setting_id');
		$finance_advisor_img = get_the_post_thumbnail_url($finance_advisor_about_us_id);
		$finance_advisor_img_class = 'has-no-image';
		if($finance_advisor_img){
			$finance_advisor_img_class = 'has-image';
		}
		?>
		<section class="content-block">
			<div class="container">
				<div class="blocks-holder <?php echo esc_attr( $finance_advisor_img_class); ?>">
					<?php if($finance_advisor_img) : ?>
						<div class="block block-img">
							<div class="block-wrap">
								<img src="<?php echo esc_url($finance_advisor_img); ?>">
							</div>
						</div>
					<?php endif; ?>
					<div class="block block-text">
						<div class="block-wrap">
							<div class="heading-block">
								<h2><?php echo esc_html( get_the_title(absint($finance_advisor_about_us_id)) ); ?></h2>
							</div>
							<div class="content">
								<?php echo esc_html( get_the_excerpt(absint($finance_advisor_about_us_id)) ); ?>
							</div>
							<div class="link-block default">
								<a href="<?php the_permalink(absint($finance_advisor_about_us_id)); ?>">
									<?php esc_html_e('Read More >>','finance-advisor') ?>
								</a>
							</div>
						</div>
					</div>
				</div>
			</div>
		</section>
	<?php
	}
endif;


/*
=================================================
Homepage Banner Section Function
@Action: finance_advisor_our_quote
=================================================
*/
if ( ! function_exists( 'finance_advisor_our_quote_fnc' ) ) :

	function finance_advisor_our_quote_fnc(){ 
		$block_quote_main_text = get_theme_mod('block_quote_main_text');
		$block_quote_sub_text = get_theme_mod('block_quote_sub_text');
		?>
		<section class="quote-block">
			<div class="container">
				<div class="quote-content has-decoration">

						<div class="quote-info">
						<?php if($block_quote_main_text): ?>
							<blockquote class="quote-text"><?php echo esc_html($block_quote_main_text); ?></blockquote>
						<?php endif;
							if($block_quote_sub_text): ?>
							<span class="author">- <?php esc_html_e('From the manager', 'finance-advisor'); ?></span>
						<?php endif;?>
						</div>

						<div class="quote-decoration">
							<i class="fas fa-quote-right"></i>
						</div>
				</div>
			</div>
		</section>
		<?php 
	}
endif;


/*
=================================================
Homepage Services Section Function
@Action: finance_advisor_our_services
=================================================
*/
if ( ! function_exists( 'finance_advisor_our_services_fnc' ) ) :

	function finance_advisor_our_services_fnc(){ 

		$finance_advisor_services_id = get_theme_mod('homepage_services_category');
		?>
		<section class="services-block">
			<div class="container">

				<!-- services header -->
				<div class="header-text">
						<h2 class="heading-text"><?php echo esc_html_e('Services', 'finance-advisor'); ?></h2>
						<div class="content">
							<p><?php echo esc_html_e('We are here to help to solve your tax problems.', 'finance-advisor'); ?></p>
						</div>
				</div>

				<!-- services posts -->
				<?php
					$finance_advisor_services_args = array(
						'post_type' => 'post',
						'cat' => absint($finance_advisor_services_id),
					);
					$finance_advisor_services_query = new WP_Query($finance_advisor_services_args);
				if($finance_advisor_services_query -> have_posts()) :
					?>
				<div class="listing-block has-four-columns">
					<?php
						while($finance_advisor_services_query->have_posts()) :
						$finance_advisor_services_query->the_post(); ?>
					<?php 
						$finance_advisor_title_service = get_the_title();
					?>
						<div class="list-col">
							<div class="col-wrap">
								<?php if (has_post_thumbnail()) : ?>
								<div class="img-wrap">
									<?php the_post_thumbnail(); ?>
								</div>
								<?php endif; ?>
								<div class="col-content">
								<div class="col-wrap-content">
									<?php if($finance_advisor_title_service) : ?>
										<h3 class="list-header"><?php the_title(); ?></h3>
									<?php endif; ?>
									<div class="info-list">
											<?php 
												the_excerpt();
											?>
										</div>
									<div class="link-block default">
										<a href="<?php the_permalink(); ?>">
											<?php esc_html_e('Read More >>', 'finance-advisor'); ?>
										</a>
									</div>
								</div>
								</div>
							</div>
						</div>
					<?php endwhile; ?>
					<?php wp_reset_postdata(); ?>
				</div>
			<?php endif;?>
			</div>
		</section>
		<?php 
	}
endif;


/*
=================================================
Homepage Client Section Function
@Action: finance_advisor_our_client
=================================================
*/
if ( ! function_exists( 'finance_advisor_our_clients_fnc' ) ) :

	function finance_advisor_our_clients_fnc(){ 
			$finance_advisor_client_cat = get_theme_mod('homepage_client_category');
			?>
			<section class="clients-block no-background">
				<div class="container">

					<div class="header-text">
							<h2 class="heading-text"><?php esc_html_e('Our Clients (Our Works)','finance-advisor'); ?></h2>
							<div class="content">
								<p><?php esc_html_e('Some of our valuable clients','finance-advisor');; ?></p>
							</div>
					</div>

				<?php $finance_advisor_client_args = array(
						'cat' => absint($finance_advisor_client_cat),
					);
					$finance_advisor_client_query = new WP_Query($finance_advisor_client_args);
					if($finance_advisor_client_query -> have_posts()) : ?>
						<div class="listing-block has-two-columns">
							<?php while($finance_advisor_client_query->have_posts()) :
								$finance_advisor_client_query->the_post();
							?>
								<div class="list-col">
									<div class="col-wrap">
										<?php if(has_post_thumbnail()): ?>
										<div class="img-wrap">
											<?php the_post_thumbnail(); ?>
										</div>
										<?php endif; ?>
										<div class="col-content">
											<div class="col-wrap-content">
												<h3 class="list-header"><?php the_title(); ?></h3>
												<div class="info-list">
													<p><?php
															the_excerpt();
															?></p>
												</div>
			
												<div class="link-block default">
													<a href="<?php the_permalink(); ?>">
														<?php echo esc_html('Read More >>', 'finance-advisor'); ?>
													</a>
												</div>
											</div>
										</div>
									</div>
								</div>
								<?php endwhile; ?>
								<?php wp_reset_postdata(); ?>
						</div>
				<?php endif; ?>
				</div>
			</section>
		<?php 
	}
endif;


/*
=================================================
Homepage Contact block Section Function
@Action: finance_advisor_contact_block
=================================================
*/
if ( ! function_exists( 'finance_advisor_contact_block_fnc' ) ) :

	function finance_advisor_contact_block_fnc(){ 
		$finance_advisor_title = get_theme_mod('contact_block_main_text');
		$finance_adviso_info = get_theme_mod('contact_block_sub_text');
		$finance_adviso_button_link = get_theme_mod('contact_readmore_link');
		?>
		<section class="contact-info-block">
			<div class="container">
				<div class="blocks-holder">
					<?php if($finance_advisor_title) : ?>
					<div class="block block-heading">
						<div class="block-wrap">
							<h4 class="heading">
								<?php echo esc_html($finance_advisor_title) ?>
							</h4>
						</div>
					</div>
					<?php endif; ?>
					<div class="block block-content">
						<div class="block-wrap">
							<?php if($finance_adviso_info) : ?>
								<div class="content">
									<p><?php echo esc_html($finance_adviso_info) ?></p>
								</div>
							<?php endif; ?>
							<?php if($finance_adviso_button_link) : ?>
								<div class="button-text">
									<a href="<?php echo esc_url($finance_adviso_button_link); ?>" class="button"><?php esc_html_e('Contact Us','finance-advisor'); ?></a>
								</div>
							<?php endif; ?>
						</div>
					</div>
				</div>
			</div>
		</section>
<?php 
	}
endif;


/*
=================================================
Homepage Blog Section Function
@Action: finance_advisor_blog_post
=================================================
*/
if ( ! function_exists( 'finance_advisor_blog_post_fnc' ) ) :

	function finance_advisor_blog_post_fnc(){ 

		$finance_advisor_blog_cat = get_theme_mod('homepage_blog_category');
		?>
		<section class="services-block home-blog-section">
			<div class="container">

				<!-- services header -->
				<div class="header-text">
						<h2 class="heading-text"><?php esc_html_e('Latest News','finance-advisor'); ?></h2>
						<div class="content">
							<p><?php esc_html_e('Lorem Ipsum is simply dummy text','finance-advisor'); ?></p>
				</div>

				<!-- blog posts -->
				<?php
					$finance_advisor_blog_args = array(
						'post_type' => 'post',
						'cat' => absint($finance_advisor_blog_cat),
					);
					$finance_advisor_blog_query = new WP_Query($finance_advisor_blog_args);
				if($finance_advisor_blog_query -> have_posts()) :
					?>
				<div class="listing-block has-four-columns">
					<?php
						while($finance_advisor_blog_query->have_posts()) :
						$finance_advisor_blog_query->the_post(); ?>
					<?php 
						$finance_advisor_title_blog = get_the_title();
					?>
						<div class="list-col">
							<div class="col-wrap">
								<?php if (has_post_thumbnail()) : ?>
								<div class="img-wrap">
									<?php the_post_thumbnail(); ?>
								</div>
								<?php endif; ?>
								<div class="col-content">
								<div class="col-wrap-content">
									<?php if($finance_advisor_title_blog) : ?>
										<h3 class="list-header"><?php the_title(); ?></h3>
									<?php endif; ?>
									<div class="info-list">
											<?php 
												the_excerpt();
											?>
										</div>
									<div class="link-block default">
										<a href="<?php the_permalink(); ?>">
											<?php esc_html_e('Read More >>', 'finance-advisor'); ?>
										</a>
									</div>
								</div>
								</div>
							</div>
						</div>
					<?php endwhile; ?>
					<?php wp_reset_postdata(); ?>
				</div>
			<?php endif;?>
			</div>
		</section>
		<?php 
	}
endif;


// navigation fallback
if ( ! function_exists( 'finance_advisor_primary_navigation_fallback' ) ) :

	/**
	 * Fallback for primary navigation.
	 *
	 * @since 1.0.0
	 */
	function finance_advisor_primary_navigation_fallback() {
		echo '<nav class="menu-menu-1-container">';
		echo '<ul id="primary-menu" class="header-nav nav-menu" aria-expanded="false">';
		echo '<li class="menu-item"><a href="' . esc_url( home_url( '/' ) ) . '">' . esc_html__( 'Home', 'finance-advisor' ) . '</a></li>';

		$args = array(
			'posts_per_page' => 5,
			'post_type'      => 'page',
			'orderby'        => 'name',
			'order'          => 'ASC',
			);

		$the_query = new WP_Query( $args );

		if ( $the_query->have_posts() ) {
			while ( $the_query->have_posts() ) {
				$the_query->the_post();
				the_title( '<li class="menu-item"><a href="' . esc_url( get_permalink() ) . '">', '</a></li>' );
			}

			wp_reset_postdata();
		}

		echo '</ul>';
		echo '</nav>';
	}

endif;
